@@ -192,7 +192,7 @@ class TestGetData:
     def test_pass_filters_by_field_id(self, good_object_id, get_three_good_field_ids, connector):
         connector.authenticate()
         data = connector.get_data(good_object_id, get_three_good_field_ids)
-        assert len(data) == len(get_three_good_field_ids)
+        assert len(data.keys()) == len(get_three_good_field_ids)
 
     @pytest.mark.get_fields
     def test_fail_bad_field_id_throws_error(self, good_object_id, bad_field_ids, connector):
